@@ -17,26 +17,21 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 */
-#include "sidebar.moc"
+#include "sidebar.h"
 
 // Qt
 #include <QAction>
-#include <QApplication>
 #include <QLabel>
 #include <QPainter>
 #include <QStyle>
-#include <QStyleOptionTabV3>
-#include <QStylePainter>
 #include <QTabBar>
 #include <QToolButton>
 #include <QVBoxLayout>
+#include <QIcon>
 
 // KDE
-#include <KDebug>
-#include <KIcon>
-#include <KIconLoader>
 #include <KGlobalSettings>
-#include <KWordWrap>
+#include <KIconLoader>
 
 // Local
 
