@@ -17,7 +17,7 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 */
-#include "thumbnailview.moc"
+#include "thumbnailview.h"
 
 // Std
 #include <math.h>
@@ -32,15 +32,16 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include <QScrollBar>
 #include <QTimeLine>
 #include <QTimer>
-#include <QToolTip>
+#include <QDrag>
+#include <QMimeData>
+#include <QDebug>
+#include <QDateTime>
 
 // KDE
-#include <KDebug>
 #include <KDirModel>
-#include <KIcon>
 #include <KIconLoader>
-#include <KGlobalSettings>
 #include <KPixmapSequence>
+#include <KUrlMimeData>
 
 // Local
 #include "abstractdocumentinfoprovider.h"
@@ -59,7 +60,7 @@ namespace Gwenview
 #undef LOG
 //#define ENABLE_LOG
 #ifdef ENABLE_LOG
-#define LOG(x) kDebug() << x
+#define LOG(x) //qDebug() << x
 #else
 #define LOG(x) ;
 #endif
@@ -79,15 +80,15 @@ static KFileItem fileItemForIndex(const QModelIndex& index)
     return qvariant_cast<KFileItem>(data);
 }
 
-static KUrl urlForIndex(const QModelIndex& index)
+static QUrl urlForIndex(const QModelIndex& index)
 {
     KFileItem item = fileItemForIndex(index);
-    return item.isNull() ? KUrl() : item.url();
+    return item.isNull() ? QUrl() : item.url();
 }
 
 struct Thumbnail
 {
-    Thumbnail(const QPersistentModelIndex& index_, const KDateTime& mtime)
+    Thumbnail(const QPersistentModelIndex& index_, const QDateTime& mtime)
         : mIndex(index_)
         , mModificationTime(mtime)
         , mFileSize(0)
@@ -127,7 +128,7 @@ struct Thumbnail
         return groupSize == qMax(mFullSize.width(), mFullSize.height());
     }
 
-    void prepareForRefresh(const KDateTime& mtime)
+    void prepareForRefresh(const QDateTime& mtime)
     {
         mModificationTime = mtime;
         mFileSize = 0;
@@ -140,7 +141,7 @@ struct Thumbnail
     }
 
     QPersistentModelIndex mIndex;
-    KDateTime mModificationTime;
+    QDateTime mModificationTime;
     /// The pix loaded from .thumbnails/{large,normal}
     QPixmap mGroupPix;
     /// Scaled version of mGroupPix, adjusted to ThumbnailView::thumbnailSize
@@ -160,7 +161,7 @@ struct Thumbnail
 };
 
 typedef QHash<QUrl, Thumbnail> ThumbnailForUrl;
-typedef QQueue<KUrl> UrlQueue;
+typedef QQueue<QUrl> UrlQueue;
 typedef QSet<QPersistentModelIndex> PersistentModelIndexSet;
 
 struct ThumbnailViewPrivate
@@ -193,8 +194,7 @@ struct ThumbnailViewPrivate
         mBusyAnimationTimeLine->setCurveShape(QTimeLine::LinearCurve);
         mBusyAnimationTimeLine->setEndFrame(mBusySequence.frameCount() - 1);
         mBusyAnimationTimeLine->setLoopCount(0);
-        QObject::connect(mBusyAnimationTimeLine, SIGNAL(frameChanged(int)),
-                         q, SLOT(updateBusyIndexes()));
+        QObject::connect(mBusyAnimationTimeLine, &QTimeLine::frameChanged, q, &ThumbnailView::updateBusyIndexes);
     }
 
     void scheduleThumbnailGeneration()
@@ -210,12 +210,12 @@ struct ThumbnailViewPrivate
     {
         Q_ASSERT(mDocumentInfoProvider);
         KFileItem item = fileItemForIndex(index);
-        KUrl url = item.url();
+        QUrl url = item.url();
         ThumbnailGroup::Enum group = ThumbnailGroup::fromPixelSize(mThumbnailSize.width());
         QPixmap pix;
         QSize fullSize;
         mDocumentInfoProvider->thumbnailForDocument(url, group, &pix, &fullSize);
-        mThumbnailForUrl[url] = Thumbnail(QPersistentModelIndex(index), KDateTime::currentLocalDateTime());
+        mThumbnailForUrl[url] = Thumbnail(QPersistentModelIndex(index), QDateTime::currentDateTime());
         q->setThumbnail(item, pix, fullSize, 0);
     }
 
@@ -247,7 +247,7 @@ struct ThumbnailViewPrivate
         const int thumbCount = qMin(indexes.count(), int(DragPixmapGenerator::MaxCount));
         QList<QPixmap> lst;
         for (int row = 0; row < thumbCount; ++row) {
-            const KUrl url = urlForIndex(indexes[row]);
+            const QUrl url = urlForIndex(indexes[row]);
             lst << mThumbnailForUrl.value(url).mAdjustedPix;
         }
         DragPixmapGenerator::DragPixmap dragPixmap = DragPixmapGenerator::generate(lst, indexes.count());
@@ -311,24 +311,15 @@ ThumbnailView::ThumbnailView(QWidget* parent)
 
     d->mScheduledThumbnailGenerationTimer.setSingleShot(true);
     d->mScheduledThumbnailGenerationTimer.setInterval(500);
-    connect(&d->mScheduledThumbnailGenerationTimer, SIGNAL(timeout()),
-            SLOT(generateThumbnailsForItems()));
+    connect(&d->mScheduledThumbnailGenerationTimer, &QTimer::timeout, this, &ThumbnailView::generateThumbnailsForItems);
 
     d->mSmoothThumbnailTimer.setSingleShot(true);
-    connect(&d->mSmoothThumbnailTimer, SIGNAL(timeout()),
-            SLOT(smoothNextThumbnail()));
+    connect(&d->mSmoothThumbnailTimer, &QTimer::timeout, this, &ThumbnailView::smoothNextThumbnail);
 
     setContextMenuPolicy(Qt::CustomContextMenu);
-    connect(this, SIGNAL(customContextMenuRequested(QPoint)),
-            SLOT(showContextMenu()));
+    connect(this, &ThumbnailView::customContextMenuRequested, this, &ThumbnailView::showContextMenu);
 
-    if (KGlobalSettings::singleClick()) {
-        connect(this, SIGNAL(clicked(QModelIndex)),
-                SLOT(emitIndexActivatedIfNoModifiers(QModelIndex)));
-    } else {
-        connect(this, SIGNAL(doubleClicked(QModelIndex)),
-                SLOT(emitIndexActivatedIfNoModifiers(QModelIndex)));
-    }
+    connect(this, &ThumbnailView::activated, this, &ThumbnailView::emitIndexActivatedIfNoModifiers);
 }
 
 ThumbnailView::~ThumbnailView()
@@ -478,7 +469,7 @@ void ThumbnailView::rowsAboutToBeRemoved(const QModelIndex& parent, int start, i
         QModelIndex index = model()->index(pos, 0, parent);
         KFileItem item = fileItemForIndex(index);
         if (item.isNull()) {
-            kDebug() << "Skipping invalid item!" << index.data().toString();
+            //qDebug() << "Skipping invalid item!" << index.data().toString();
             continue;
         }
 
@@ -505,15 +496,15 @@ void ThumbnailView::rowsInserted(const QModelIndex& parent, int start, int end)
     rowsInsertedSignal(parent, start, end);
 }
 
-void ThumbnailView::dataChanged(const QModelIndex& topLeft, const QModelIndex& bottomRight)
+void ThumbnailView::dataChanged(const QModelIndex& topLeft, const QModelIndex& bottomRight, const QVector<int> &roles)
 {
-    QListView::dataChanged(topLeft, bottomRight);
+    QListView::dataChanged(topLeft, bottomRight, roles);
     bool thumbnailsNeedRefresh = false;
     for (int row = topLeft.row(); row <= bottomRight.row(); ++row) {
         QModelIndex index = model()->index(row, 0);
         KFileItem item = fileItemForIndex(index);
         if (item.isNull()) {
-            kWarning() << "Invalid item for index" << index << ". This should not happen!";
+            qWarning() << "Invalid item for index" << index << ". This should not happen!";
             GV_FATAL_FAILS;
             continue;
         }
@@ -525,7 +516,7 @@ void ThumbnailView::dataChanged(const QModelIndex& topLeft, const QModelIndex& b
             // result this method will also be called for views which are not
             // currently visible, and do not yet have a thumbnail for the
             // modified url.
-            KDateTime mtime = item.time(KFileItem::ModificationTime);
+            QDateTime mtime = item.time(KFileItem::ModificationTime);
             if (it->mModificationTime != mtime || it->mFileSize != item.size()) {
                 // dataChanged() is called when the file changes but also when
                 // the model fetched additional data such as semantic info. To
@@ -587,7 +578,7 @@ void ThumbnailView::setBrokenThumbnail(const KFileItem& item)
         // support for video thumbnails so we show the mimetype icon instead of
         // a broken image icon
         ThumbnailGroup::Enum group = ThumbnailGroup::fromPixelSize(d->mThumbnailSize.height());
-        QPixmap pix = item.pixmap(ThumbnailGroup::pixelSize(group));
+        QPixmap pix = KIconLoader::global()->loadMimeTypeIcon(item.iconName(), KIconLoader::Desktop, d->mThumbnailSize.height());
         thumbnail.initAsIcon(pix);
     } else if (kind == MimeTypeUtils::KIND_DIR) {
         // Special case for folders because ThumbnailProvider does not return a
@@ -611,7 +602,7 @@ QPixmap ThumbnailView::thumbnailForIndex(const QModelIndex& index, QSize* fullSi
         }
         return QPixmap();
     }
-    KUrl url = item.url();
+    QUrl url = item.url();
 
     // Find or create Thumbnail instance
     ThumbnailForUrl::Iterator it = d->mThumbnailForUrl.find(url);
@@ -626,7 +617,8 @@ QPixmap ThumbnailView::thumbnailForIndex(const QModelIndex& index, QSize* fullSi
     if (kind == MimeTypeUtils::KIND_ARCHIVE || kind == MimeTypeUtils::KIND_DIR) {
         int groupSize = ThumbnailGroup::pixelSize(ThumbnailGroup::fromPixelSize(d->mThumbnailSize.height()));
         if (thumbnail.mGroupPix.isNull() || thumbnail.mGroupPix.height() < groupSize) {
-            QPixmap pix = item.pixmap(groupSize);
+            QPixmap pix = KIconLoader::global()->loadMimeTypeIcon(item.iconName(), KIconLoader::Desktop, d->mThumbnailSize.height());
+
             thumbnail.initAsIcon(pix);
             if (kind == MimeTypeUtils::KIND_ARCHIVE) {
                 // No thumbnails for archives
@@ -674,7 +666,7 @@ bool ThumbnailView::isModified(const QModelIndex& index) const
     if (!d->mDocumentInfoProvider) {
         return false;
     }
-    KUrl url = urlForIndex(index);
+    QUrl url = urlForIndex(index);
     return d->mDocumentInfoProvider->isModified(url);
 }
 
@@ -683,7 +675,7 @@ bool ThumbnailView::isBusy(const QModelIndex& index) const
     if (!d->mDocumentInfoProvider) {
         return false;
     }
-    KUrl url = urlForIndex(index);
+    QUrl url = urlForIndex(index);
     return d->mDocumentInfoProvider->isBusy(url);
 }
 
@@ -716,7 +708,7 @@ void ThumbnailView::dragMoveEvent(QDragMoveEvent* event)
 
 void ThumbnailView::dropEvent(QDropEvent* event)
 {
-    const KUrl::List urlList = KUrl::List::fromMimeData(event->mimeData());
+    const QList<QUrl> urlList = KUrlMimeData::urlsFromMimeData(event->mimeData());
     if (urlList.isEmpty()) {
         return;
     }
@@ -725,7 +717,7 @@ void ThumbnailView::dropEvent(QDropEvent* event)
     if (destIndex.isValid()) {
         KFileItem item = fileItemForIndex(destIndex);
         if (item.isDir()) {
-            KUrl destUrl = item.url();
+            QUrl destUrl = item.url();
             d->mThumbnailViewHelper->showMenuForUrlDroppedOnDir(this, urlList, destUrl);
             return;
         }
@@ -881,7 +873,7 @@ void ThumbnailView::generateThumbnailsForItems()
 void ThumbnailView::updateThumbnail(const QModelIndex& index)
 {
     KFileItem item = fileItemForIndex(index);
-    KUrl url = item.url();
+    QUrl url = item.url();
     if (d->mDocumentInfoProvider && d->mDocumentInfoProvider->isModified(url)) {
         d->updateThumbnailForModifiedDocument(index);
     } else {
@@ -932,7 +924,7 @@ void ThumbnailView::smoothNextThumbnail()
         return;
     }
 
-    KUrl url = d->mSmoothThumbnailQueue.dequeue();
+    QUrl url = d->mSmoothThumbnailQueue.dequeue();
     ThumbnailForUrl::Iterator it = d->mThumbnailForUrl.find(url);
     GV_RETURN_IF_FAIL2(it != d->mThumbnailForUrl.end(), url << "not in mThumbnailForUrl.");
 
@@ -950,9 +942,9 @@ void ThumbnailView::smoothNextThumbnail()
 
 void ThumbnailView::reloadThumbnail(const QModelIndex& index)
 {
-    KUrl url = urlForIndex(index);
+    QUrl url = urlForIndex(index);
     if (!url.isValid()) {
-        kWarning() << "Invalid url for index" << index;
+        qWarning() << "Invalid url for index" << index;
         return;
     }
     ThumbnailProvider::deleteImageThumbnail(url);
